==> kurumii-0.3.tar.gz: kurumii-0.3/kurumii/ascii.py <==
def print_ascii(text):

    ascii_art = {
    'A': [
        "           ",
        "    /\     ",
        "   /  \    ",
        "  / /\ \   ",
        " / ____ \  ",
        "/_/    \_\\ ",
        "           "
        

    ],
    'B': [
        " ____   ",
        "|  _ \  ",
        "| |_) | ",
        "|  _ <  ",
        "| |_) | ",
        "|____/  ",
        "        "
    ],
    'C': [
        "  _____  ",
        " / ____| ",
        "| |      ",
        "| |      ",
        "| |____  ",
        " \_____| ",
        "         "
    ],
    'D': [
        " _____   ",
        "|  __ \  ",
        "| |  | | ",
        "| |  | | ",
        "| |__| | ",
        "|_____/  ",
        "         "
    ],
    'E': [
        " _____  ",
        "| ____| ",
        "| |___  ",
        "| ____| ",
        "| |___  ",
        "|_____| ",
        "        "
    ],
    'F': [
        " _____   ",
        "|  ____| ",
        "| |__    ",
        "|  __|   ",
        "| |      ",
        "|_|      ",
        "         "
    ],
    'G': [
        "  _____  ",
        " / ____| ",
        "| |  __  ",
        "| | |_ | ",
        "| |__| | ",
        " \_____| ",
        "         "
    ],
    'H': [
        " _    _  ",
        "| |  | | ",
        "| |__| | ",
        "|  __  | ",
        "| |  | | ",
        "|_|  |_| ",
        "         "
    ],
    'I': [
        " _____  ",
        "|_   _| ",
        "  | |   ",
        "  | |   ",
        " _| |_  ",
        "|_____| ",
        "        "
    ],
    'J': [
        "      _  ",
        "     | | ",
        "     | | ",
        " _   | | ",
        "| |__| | ",
        " \____/  ",
        "         "
    ],
    'K': [
        " _  __ ",
        "| |/ / ",
        "| ' /  ",
        "|  <   ",
        "| . \  ",
        "|_|\_\ ",
        "       "
    ],
    'L': [
        " _       ",
        "| |      ",
        "| |      ",
        "| |      ",
        "| |____  ",
        "|______| ",
        "         "
    ],
    'M': [
        " __  __  ",
        "|  \/  | ",
        "| \  / | ",
        "| |\/| | ",
        "| |  | | ",
        "|_|  |_| ",
        "         "
    ],
    'N': [
        " _   _  ",
        "| \ | | ",
        "|  \| | ",
        "| . ` | ",
        "| |\  | ",
        "|_| \_| ",
        "        "
    ],
    'O': [
        "  ____   ",
        " / __ \  ",
        "| |  | | ",
        "| |  | | ",
        "| |__| | ",
        " \____/  ",
        "         "
    ],
    'P': [
        " _____   ",
        "|  __ \  ",
        "| |__) | ",
        "|  ___/  ",
        "| |      ",
        "|_|      ",
        "         "
    ],
    'Q': [
        "  ____   ",
        " / __ \  ",
        "| |  | | ",
        "| |  | | ",
        "| |__| | ",
        " \___\_\ ",
        "         "
    ],
    'R': [
        " _____   ",
        "|  __ \  ",
        "| |__) | ",
        "|  _  /  ",
        "| | \ \  ",
        "|_|  \_\ ",
        "         "
    ],
    'S': [
        "  _____  ",
        " / ____| ",
        "| (___   ",
        " \___ \  ",
        " ____) | ",
        "|_____/  ",
        "         "
],
    'T': [
        " _______  ",
        "|__   __| ",
        "   | |    ",
        "   | |    ",
        "   | |    ",
        "   |_|    ",
        "          "
    ],
    'U': [
        " _    _  ",
        "| |  | | ",
        "| |  | | ",
        "| |  | | ",
        "| |__| | ",
        " \____/  ",
        "         "
    ],
    'V': [
        " _    _  ",
        "| |  | | ",
        "| |  | | ",
        "| |  | | ",
        " \ \/ /  ",
        "  \__/   ",
        "         "
    ],
    'W': [
        " _        _  ",
        "| |      | | ",
        "| |  __  | | ",
        "| | /  \ | | ",
        "| |/ /\ \| | ",
        "|___/  \___| ",
        "             "
    ],
    'X': [
        
        " __   __  ",
        " \ \ / /  ",
        "  \ V /   ",
        "   > <    ",
        "  / . \   ",
        " /_/ \_\\  ",
        "          "
    ],
    'Y': [
        "__     __  ",
        "\ \   / /  ",
        " \ \_/ /   ",
        "  \   /    ",
        "   | |     ",
        "   |_|     ",
        "           "
    ],
    'Z': [
        " _______   ",
        "|____  /   ",
        "    / /    ",
        "   / /     ",
        "  / /____  ",
        " /_______| ",
        "            "
    ],
#####################################################################
        'a': [
        "        ",
        "        ",
        "  __ _  ",
        " / _` | ",
        "| (_| | ",
        " \__,_| ",

        "        "        
    ],
    "b":[  
        " _     ",
        "| |    ",
        "| |__  ",
        "| '_ \ ",
        "| |_) |",
        "|_.__/ ",
        "       "
    ],
    "c":[
        "       ",
        "       ",
        "  ___  ",
        " / __| ",
        "| (__  ",
        " \___| ",
        "       "
    ],
    "d":[
        "     _  ",
        "    | | ",
        "  __| | ",
        " / _` | ",
        "| (_| | ",
        " \__,_| ",
        "        "
    ],
    " ":[ #space holder
        "    ",
        "    ",
        "    ",
        "    ",
        "    " ,
        "    " ,
        "    "
    ], 
    "e": [
        "       ",
        "       ",
        "  ___  ",
        " / _ \\ ",
        "|  __/ ",
        " \___| ",
        "       "
    ],
    "f": [
        "  __  ",
        " / _| ",
        "| |_  ",
        "|  _| ",
        "| |   " ,
        "|_|   ",
        "      "
    ],
    "g": [
        "  __ _  ",
        " / _` | ",
        "| (_| | ",
        " \__, | ",
        "  __/ | ",
        " |___/  ",
        "        "
    ],
    "'":[
        " _ ",
        "( )",
        "|/ ",
        "   ",
        "   ",  
        "   ",
        "   " 
    ],
    ".":[
        "   ",
        "   ",
        "   ", 
        "   ",
        " _ ",
        "(_)",
        "   "
    ],
    "h":[
    " _      ",
    "| |     ",
    "| |__   ",
    "| '_ \  ",
    "| | | | ",
    "|_| |_| ",
    "        "
    ],
    "i":[
"    ",
"(_) ",
" _  ",
"| | ",
"| | ",
"|_| ",
"    "
    ],
    "j":[
        
"     __  ",
"    |__| ",
"    |  | ",
"    |  | ",
"/\__|  | ",
"\______| ",
"         "
    ],
    "k":[
" _     ",
"| |    ",
"| | __ ",
"| |/ / ",
"|   <  ",
"|_|\_\\ ",
"       "
    ],
    "l":[
" _    ",
"| |   ",
"| |   ",
"| |   ",
"| |_  ",
"|___| ",
"      "
    ],
    "m":[
        
"            ",
"            ",
" _ __ ___   ",
"| '_ ` _ \  ",
"| | | | | | ",
"|_| |_| |_| ",
"            "
    ],
    "n":[
"        ",
"        ",       
" _ __   ",
"| '_ \  ",
"| | | | ",
"|_| |_| ",
"        "
    ],
    "o":[
"        ",
"        ",
"  ___   ",
" / _ \  ",
"| (_) | ",
" \___/  ",
"        "
    ],
    "p":[
"        ",
" _ __   ",
"| '_ \  ",
"| |_) | ",
"| .__/  ",
"|_|     ",
"        "
    ],
    "q":[
"  ____  ",
" / _` | ",
"| (_| | ",
" \__, | ",
"    | | ",
"    |_| ",
"        "
    ],
    "r":[
"       ", 
"       ",
" _ __  ",
"| '__| ",
"| |    ",
"|_|    ",
"       "
    ],
    "s":[
"      ",
"      ",
" ___  ",
"/ __| ",
"\__ \\ ",
"|___/ ",
"      "
],
    "t":[
" _    ",
"| |   ",
"| |_  ",
"| __| ",
"| |_  ",
" \__| ",
"      "
],
    "u":[
"        ",
"        ",        
" _   _  ",
"| | | | ",
"| |_| | ",
" \__,_| ",
"        "
],
    "v":[
"        ",
"        ",
"__   __ ",
"\ \ / / ",
" \ V /  ",
"  \_/   ",
"        "
],
    "w":[
"           ", 
"           ",
"__      __ ",
"\ \ /\ / / ",
" \ V  V /  ",
"  \_/\_/   ",
"           "
],
    "x":[
"       ",
"       ",
"__  __ ",
"\ \/ / ",
" >  <  ",
"/_/\_\\ ",
"       "
],
    "y":[
" _   _  ",  
"| | | | ",
"| |_| | ",
" \__, | ",
"  __/ | ",
" |___/  ",
"        "
],
    "z":[
"      ",
"      ",
" ____ ",
"|_  / ",
" / /  ",
"/___| ",
"      "
],
",":[
"    ",
"    ",
"    ",
" _  ",
"( ) ",
"|/  ",
"    "
],
"?":[
" ___   ",
"|__ \  ",
"   ) | ",
"  / /  ",
" |_|   ",
" (_)   ",
"       "
]
}
    
    # Concatenate corresponding lines of ASCII art for each letter in the text
    combined_art = ""
    for line_num in range(len(ascii_art['A'])):
        for char in text:
            if char in ascii_art:
                combined_art += ascii_art[char][line_num]  # Concatenate ASCII art for each character
            else:
                return print(f' Unsuported character: {char}')
        combined_art += "\n"  # Add a newline after each line of characters

    # Print the combined ASCII art
    print(combined_art)

==> kurumii-1.4.8.3.tar.gz: kurumii-1.4.8.3/kurumii/ascii.py <==
ascii_art_ = {
    'A': [
        "           ",
        "    /\     ",
        "   /  \    ",
        "  / /\ \   ",
        " / ____ \  ",
        "/_/    \_\\ ",
        "           "
        

    ],
    'B': [
        " ____   ",
        "|  _ \  ",
        "| |_) | ",
        "|  _ <  ",
        "| |_) | ",
        "|____/  ",
        "        "
    ],
    'C': [
        "  _____  ",
        " / ____| ",
        "| |      ",
        "| |      ",
        "| |____  ",
        " \_____| ",
        "         "
    ],
    'D': [
        " _____   ",
        "|  __ \  ",
        "| |  | | ",
        "| |  | | ",
        "| |__| | ",
        "|_____/  ",
        "         "
    ],
    'E': [
        " _____  ",
        "| ____| ",
        "| |___  ",
        "| ____| ",
        "| |___  ",
        "|_____| ",
        "        "
    ],
    'F': [
        " _____   ",
        "|  ____| ",
        "| |__    ",
        "|  __|   ",
        "| |      ",
        "|_|      ",
        "         "
    ],
    'G': [
        "  _____  ",
        " / ____| ",
        "| |  __  ",
        "| | |_ | ",
        "| |__| | ",
        " \_____| ",
        "         "
    ],
    'H': [
        " _    _  ",
        "| |  | | ",
        "| |__| | ",
        "|  __  | ",
        "| |  | | ",
        "|_|  |_| ",
        "         "
    ],
    'I': [
        " _____  ",
        "|_   _| ",
        "  | |   ",
        "  | |   ",
        " _| |_  ",
        "|_____| ",
        "        "
    ],
    'J': [
        "      _  ",
        "     | | ",
        "     | | ",
        " _   | | ",
        "| |__| | ",
        " \____/  ",
        "         "
    ],
    'K': [
        " _  __ ",
        "| |/ / ",
        "| ' /  ",
        "|  <   ",
        "| . \  ",
        "|_|\_\ ",
        "       "
    ],
    'L': [
        " _       ",
        "| |      ",
        "| |      ",
        "| |      ",
        "| |____  ",
        "|______| ",
        "         "
    ],
    'M': [
        " __  __  ",
        "|  \/  | ",
        "| \  / | ",
        "| |\/| | ",
        "| |  | | ",
        "|_|  |_| ",
        "         "
    ],
    'N': [
        " _   _  ",
        "| \ | | ",
        "|  \| | ",
        "| . ` | ",
        "| |\  | ",
        "|_| \_| ",
        "        "
    ],
    'O': [
        "  ____   ",
        " / __ \  ",
        "| |  | | ",
        "| |  | | ",
        "| |__| | ",
        " \____/  ",
        "         "
    ],
    'P': [
        " _____   ",
        "|  __ \  ",
        "| |__) | ",
        "|  ___/  ",
        "| |      ",
        "|_|      ",
        "         "
    ],
    'Q': [
        "  ____   ",
        " / __ \  ",
        "| |  | | ",
        "| |  | | ",
        "| |__| | ",
        " \___\_\ ",
        "         "
    ],
    'R': [
        " _____   ",
        "|  __ \  ",
        "| |__) | ",
        "|  _  /  ",
        "| | \ \  ",
        "|_|  \_\ ",
        "         "
    ],
    'S': [
        "  _____  ",
        " / ____| ",
        "| (___   ",
        " \___ \  ",
        " ____) | ",
        "|_____/  ",
        "         "
],
    'T': [
        " _______  ",
        "|__   __| ",
        "   | |    ",
        "   | |    ",
        "   | |    ",
        "   |_|    ",
        "          "
    ],
    'U': [
        " _    _  ",
        "| |  | | ",
        "| |  | | ",
        "| |  | | ",
        "| |__| | ",
        " \____/  ",
        "         "
    ],
    'V': [
        " _    _  ",
        "| |  | | ",
        "| |  | | ",
        "| |  | | ",
        " \ \/ /  ",
        "  \__/   ",
        "         "
    ],
    'W': [
        " _        _  ",
        "| |      | | ",
        "| |  __  | | ",
        "| | /  \ | | ",
        "| |/ /\ \| | ",
        "|___/  \___| ",
        "             "
    ],
    'X': [
        
        " __   __  ",
        " \ \ / /  ",
        "  \ V /   ",
        "   > <    ",
        "  / . \   ",
        " /_/ \_\\  ",
        "          "
    ],
    'Y': [
        "__     __  ",
        "\ \   / /  ",
        " \ \_/ /   ",
        "  \   /    ",
        "   | |     ",
        "   |_|     ",
        "           "
    ],
    'Z': [
        " _______   ",
        "|____  /   ",
        "    / /    ",
        "   / /     ",
        "  / /____  ",
        " /_______| ",
        "            "
    ],
        'a': [
        "        ",
        "        ",
        "  __ _  ",
        " / _` | ",
        "| (_| | ",
        " \__,_| ",

        "        "        
    ],
    "b":[  
        " _     ",
        "| |    ",
        "| |__  ",
        "| '_ \ ",
        "| |_) |",
        "|_.__/ ",
        "       "
    ],
    "c":[
        "       ",
        "       ",
        "  ___  ",
        " / __| ",
        "| (__  ",
        " \___| ",
        "       "
    ],
    "d":[
        "     _  ",
        "    | | ",
        "  __| | ",
        " / _` | ",
        "| (_| | ",
        " \__,_| ",
        "        "
    ],
    " ":[ #space holder
        "    ",
        "    ",
        "    ",
        "    ",
        "    " ,
        "    " ,
        "    "
    ], 
    "e": [
        "       ",
        "       ",
        "  ___  ",
        " / _ \\ ",
        "|  __/ ",
        " \___| ",
        "       "
    ],
    "f": [
        "  __  ",
        " / _| ",
        "| |_  ",
        "|  _| ",
        "| |   " ,
        "|_|   ",
        "      "
    ],
    "g": [
        "  __ _  ",
        " / _` | ",
        "| (_| | ",
        " \__, | ",
        "  __/ | ",
        " |___/  ",
        "        "
    ],
    "'":[
        " _ ",
        "( )",
        "|/ ",
        "   ",
        "   ",  
        "   ",
        "   " 
    ],
    ".":[
        "   ",
        "   ",
        "   ", 
        "   ",
        " _ ",
        "(_)",
        "   "
    ],
    "h":[
    " _      ",
    "| |     ",
    "| |__   ",
    "| '_ \  ",
    "| | | | ",
    "|_| |_| ",
    "        "
    ],
    "i":[
"    ",
"(_) ",
" _  ",
"| | ",
"| | ",
"|_| ",
"    "
    ],
    "j":[
        
"     __  ",
"    |__| ",
"    |  | ",
"    |  | ",
"/\__|  | ",
"\______| ",
"         "
    ],
    "k":[
" _     ",
"| |    ",
"| | __ ",
"| |/ / ",
"|   <  ",
"|_|\_\\ ",
"       "
    ],
    "l":[
" _    ",
"| |   ",
"| |   ",
"| |   ",
"| |_  ",
"|___| ",
"      "
    ],
    "m":[
        
"            ",
"            ",
" _ __ ___   ",
"| '_ ` _ \  ",
"| | | | | | ",
"|_| |_| |_| ",
"            "
    ],
    "n":[
"        ",
"        ",       
" _ __   ",
"| '_ \  ",
"| | | | ",
"|_| |_| ",
"        "
    ],
    "o":[
"        ",
"        ",
"  ___   ",
" / _ \  ",
"| (_) | ",
" \___/  ",
"        "
    ],
    "p":[
"        ",
" _ __   ",
"| '_ \  ",
"| |_) | ",
"| .__/  ",
"|_|     ",
"        "
    ],
    "q":[
"  ____  ",
" / _` | ",
"| (_| | ",
" \__, | ",
"    | | ",
"    |_| ",
"        "
    ],
    "r":[
"       ", 
"       ",
" _ __  ",
"| '__| ",
"| |    ",
"|_|    ",
"       "
    ],
    "s":[
"      ",
"      ",
" ___  ",
"/ __| ",
"\__ \\ ",
"|___/ ",
"      "
],
    "t":[
" _    ",
"| |   ",
"| |_  ",
"| __| ",
"| |_  ",
" \__| ",
"      "
],
    "u":[
"        ",
"        ",        
" _   _  ",
"| | | | ",
"| |_| | ",
" \__,_| ",
"        "
],
    "v":[
"        ",
"        ",
"__   __ ",
"\ \ / / ",
" \ V /  ",
"  \_/   ",
"        "
],
    "w":[
"           ", 
"           ",
"__      __ ",
"\ \ /\ / / ",
" \ V  V /  ",
"  \_/\_/   ",
"           "
],
    "x":[
"       ",
"       ",
"__  __ ",
"\ \/ / ",
" >  <  ",
"/_/\_\\ ",
"       "
],
    "y":[
" _   _  ",  
"| | | | ",
"| |_| | ",
" \__, | ",
"  __/ | ",
" |___/  ",
"        "
],
    "z":[
"      ",
"      ",
" ____ ",
"|_  / ",
" / /  ",
"/___| ",
"      "
],
",":[
"    ",
"    ",
"    ",
" _  ",
"( ) ",
"|/  ",
"    "
],
"?":[
" ___   ",
"|__ \  ",
"   ) | ",
"  / /  ",
" |_|   ",
" (_)   ",
"       "
],
"-":[
"         ",   
"         ",
" ______  ",
"|______| ",
"         ",     
"         ",
"         "
         
         

],
"_":[ 
"         ",
"         ",
"         ",
"         ",
" ______  ",
"|______| ",
"         "
],
"1":[   
" __  ",
"/_ | ",
" | | ",
" | | ",
" | | ",
" |_| ",
"     "
],
"2":[
" ___   ",
"|__ \  ",
"   ) | ",
"  / /  ",
" / /_  ",
"|____| ",
"       "
],
"3":[      
" ____   ",
"|___ \  ",
"  __) | ",
" |__ <  ",
" ___) | ",
"|____/  ",
"        "
],
"4":[
    
" _  _    ",
"| || |   ",
"| || |_  ",
"|__   _| ",
"   | |   ",
"   |_|   ",
"         "
         

],
"5":[
" _____  ",
"| ____| ",
"| |__   ",
"|___ \  ",
" ___) | ",
"|____/  ",
"        "
],
"6":[
    
"   __   ",
"  / /   ",
" / /_   ",
"| '_ \  ",
"| (_) | ",
" \___/  ",
"        "
],
"7":[
" ______  ",
"|____  | ",
"    / /  ",
"   / /   ",
"  / /    ",
" /_/     ",
"         "
],
"8":[   
"  ___   ",
" / _ \  ",
"| (_) | ",
" > _ <  ",
"| (_) | ",
" \___/  ",
"        "
],
"9":[
"  ___   ",
" / _ \  ",
"| (_) | ",
" \__, | ",
"   / /  ",
"  /_/   ",
"        "
],
"0":[
    
"  ___   ",
" / _ \  ",
"| | | | ",
"| | | | ",
"| |_| | ",
" \___/  ",
"        "
],
"+":[
    
"        ",
"   _    ",
" _| |_  ",
"|_   _| ",
"  |_|   ",
"        ",
"        "
        
        
        

],
"=":[
    
"         ",   
" ______  ",
"|______| ",
" ______  ",
"|______| ",
"         ",
"         "
         
         

]

}

def print_ascii(text):

    combined_art = ""
    for line_num in range(len(ascii_art_['A'])):
        for char in text:
            if char in ascii_art_:
                combined_art += ascii_art_[char][line_num]  # Concatenate ASCII art for each character
            else:
                return print(f' Unsuported character: {char}')
        combined_art += "\n"  # Add a newline after each line of characters

    print(combined_art)

def ascii_art(text):
    combined_art = ""
    for line_num in range(len(ascii_art_['A'])):
        for char in text:
            if char in ascii_art_:
                combined_art += ascii_art_[char][line_num]  # Concatenate ASCII art for each character
            else:
                return print(f' Unsuported character: {char}')
        combined_art += "\n"  # Add a newline after each line of characters

    return(combined_art)

def print_ascii(text):

    combined_art = ""
    for line_num in range(len(ascii_art_['A'])):
        for char in text:
            if char in ascii_art_:
                combined_art += ascii_art_[char][line_num]  # Concatenate ASCII art for each character
            else:
                return print(f' Unsuported character: {char}')
        combined_art += "\n"  # Add a newline after each line of characters

    print(combined_art)

def print_ascii_colored(text, hex_color):
    """
    Print the text in the specified color.
    
    - Args:
        - text (str): The text that should be printed
        - hex_color: The color in hex
    
    - Returns:
        - None
    """
    color_codes = {
        "green": "0;255;0",
        "red": "255;0;0",
        "yellow": "255;255;0",
        "blue": "0;0;255",
        "magenta": "255;0;255",
        "cyan": "0;255;255",
        "white": "255;255;255",
        "black": "0;0;0",
        "gray": "128;128;128",
        "lightgray": "211;211;211",
        "darkgray": "169;169;169",
        "lightblue": "173;216;230",
        "lightgreen": "144;238;144",
        "lightcyan": "224;255;255",
        "lightred": "255;182;193",
        "pink": "255;192;203",
    }
    if hex_color.lower() in color_codes:
        color = color_codes[hex_color.lower()]
    else:
        try:
            if hex_color[0] == "#":
                hex_color = hex_color[1:]
            if len(hex_color) != 6:
                raise ValueError("Hex color must be 6 characters long.")
            r = int(hex_color[0:2], 16)
            g = int(hex_color[2:4], 16)
            b = int(hex_color[4:6], 16)
            color = f"{r};{g};{b}"
        except ValueError as e:
            print(f"Error: {e}")
            return
    combined_art = ""
    for line_num in range(len(ascii_art_['A'])):
        for char in text:
            if char in ascii_art_:
                combined_art += ascii_art_[char][line_num]  # Concatenate ASCII art for each character
            else:
                return print(f' Unsuported character: {char}')
        combined_art += "\n"  # Add a newline after each line of characters
    print(f"\033[38;2;{color}m{combined_art}\033[0m")



def ascii_art_colored(text, hex_color):
    """
    Print the text in the specified color.
    
    :param text: The text to be printed.
    :param color: The color in which the text should be printed.
                  Options: 'green', 'red', 'yellow', 'blue', 'magenta', 'cyan', 'white', 'black', 'gray', 
                           'lightgray', 'darkgray', 'lightblue', 'lightgreen', 'lightcyan', 'lightred', 'pink'
                  Optionally, the color can be specified as a hexadecimal string.
                  Optional: False
    """
    color_codes = {
        "green": "0;255;0",
        "red": "255;0;0",
        "yellow": "255;255;0",
        "blue": "0;0;255",
        "magenta": "255;0;255",
        "cyan": "0;255;255",
        "white": "255;255;255",
        "black": "0;0;0",
        "gray": "128;128;128",
        "lightgray": "211;211;211",
        "darkgray": "169;169;169",
        "lightblue": "173;216;230",
        "lightgreen": "144;238;144",
        "lightcyan": "224;255;255",
        "lightred": "255;182;193",
        "pink": "255;192;203",
    }
    if hex_color.lower() in color_codes:
        color = color_codes[hex_color.lower()]
    else:
        try:
            if hex_color[0] == "#":
                hex_color = hex_color[1:]
            if len(hex_color) != 6:
                raise ValueError("Hex color must be 6 characters long.")
            r = int(hex_color[0:2], 16)
            g = int(hex_color[2:4], 16)
            b = int(hex_color[4:6], 16)
            color = f"{r};{g};{b}"
        except ValueError as e:
            print(f"Error: {e}")
            return
    combined_art = ""
    for line_num in range(len(ascii_art_['A'])):
        for char in text:
            if char in ascii_art_:
                combined_art += ascii_art_[char][line_num]  # Concatenate ASCII art for each character
            else:
                return print(f' Unsuported character: {char}')
        combined_art += "\n"  # Add a newline after each line of characters
    return(f"\033[38;2;{color}m{combined_art}\033[0m")
